/******************************
 * The Fredericks Company
 * www.frederickscompany.com
 * sales@frederickscompany.com
 *
 * RS-485 Arduino Communication
 * 
 * Code for Arduino Uno to read tilt and temperature from
 * a sensor mounted on the 1-6200-008 signal conditioner
 * using an RS-485 signal.
 * 
 * Output: print X, Y, and Temperature to serial port every 1 second
 *
 * Rev -
 * 
 * */

#include <SoftwareSerial.h>

#define RX 10 // define pin 10 as receive
#define TX 11 // define pin 11 as transmit
#define EN 2 // define pin 2 as enable

SoftwareSerial Sensor(RX, TX); // initialize the software serial port transmit and receive pins

void setup() {
    Sensor.begin(9600); // set the baud rate for the 1-6200-008 communication
    Serial.begin(9600); // set the baud rate for the Arduino serial communication
    pinMode(EN, OUTPUT); // make EN an output pin
}

void loop() {
    char x[20], y[20], temperature[20]; // initialize x, y, temperature
    int b = 0;

    digitalWrite(EN, HIGH); // enable transmission
    Sensor.print("*9911#"); // send x axis command
    digitalWrite(EN, LOW); // enable reception
    delay(25); // wait for sensor to respond
    b = 0;
    while (Sensor.available()) {
        x[b++] = Sensor.read(); // store response from sensor in a char array
    }
    x[b - 2] = '\0'; // null character termination for string

    digitalWrite(EN, HIGH); // enable transmission
    Sensor.print("*9921#"); // send y axis command
    digitalWrite(EN, LOW); // enable reception
    delay(25);
    b = 0;
    while (Sensor.available()) {
        y[b++] = Sensor.read(); // store response in char array
    }
    y[b - 2] = '\0'; // null character termination for string

    digitalWrite(EN, HIGH); // enable transmission
    Sensor.print("*9941#"); // send temperature command
    digitalWrite(EN, LOW); // enable reception
    delay(25);
    b = 0;
    while (Sensor.available()) {
        temperature[b++] = Sensor.read(); // store response
    }
    temperature[b - 2] = '\0'; // null character

    // Output the results to the serial monitor
    Serial.print("X: ");
    Serial.println(x);
    Serial.print("Y: ");
    Serial.println(y);
    Serial.print("T: ");

    String s = String(temperature); // make the char temperature array into a string
    double t = s.toDouble(); // make that string into a double
    Serial.println((((t / 1023) * 5) - 0.5) / 0.01); // convert the temp output to get temp in degrees C

    Serial.println("\n");

    delay(1000);
}